
# Load model functions ----------------------------------------------------

source(file = ".../Coexistence_Model_Functions.R")

# options(scipen = 10) #universal setting for non-scientific notation

# Validation setup --------------------------------------------------------

## Units
# r  = #growth rate/hour; round(logb(2)/(20/60)*(1/(S0/1)), 2)
# e  = #/hour; <<variable>>
# m  = #/hour; round(log(1-0.027)/(15/60), 2)
# q  = #resource/population; round(12/18.6, 2)
# g  = #/unit enzyme/hour; round((86474.88*1.05/(1000*1.25))/(1/1.9), 2) # 1/hour * 1/((K g enzyme)/(l solution))
# qz = #unit enzyme/biomass; <<define units to set to 1>>
# mz = #/hour; round(log(0.5)/0.66, 2)
# d  = #cell_dist/hour; <<fixed>>
# a  = #/hour; round(263/23200,2)
# S0 = #mg/l; round((2+0.5)/2,2)

## Literature parameter values
pars  <- c(r  = 1.66,
           e  = 0.1,
           m  = 0.11,
           q  = 0.65,
           g  = 138.01,
           qz = 1,
           mz = 1.05,
           d  = 0.1,
           a  = 0.01,
           S0 = 1.25)

yini0 <- c(NE = NE_mono_eq(pars),
           NC = 0.001,
           E  = NA,
           RE = REeq(pars),
           RC = REeq(pars),
           S  = NA)

yini0["E"] <- with(as.list(pars), qz*e*yini0["NE"]/mz)
yini0["S"] <- with(as.list(pars), S0*a/(yini0["E"]*g+a))

yini1 <- yini0
yini1["NC"] <- 0

yini <- c(NE = NEeq(pars)[1],
          NC = NCeq(pars),
          E  = Eeq(pars)[1],
          RE = REeq(pars),
          RC = RCeq(pars),
          S  = Seq(pars)[1])

yini

# Test solver -------------------------------------------------------------

# times <- seq(0, 5000, by = 1)
# out_mono <- ode(y = yini1, times = times, func = ECmod, parms = pars) # NE monoculture
# out_inv <- ode(y = yini0, times = times, func = ECmod, parms = pars) # NC invasion (added at low initial pop)
# out_mix <- ode(y = yini, times = times, func = ECmod, parms = pars) # NE+NC mixed together (both same initial pop)
# 
# matplot(x = out_mono[, 1],
#         y = out_mono[, c(2,4:7)],
#         type = "l",
#         ylim = c(1e-3, 0.13),
#         xlab = "time",
#         ylab = "abundance",
#         log = "y",
#         col = c(1, 3:6),
#         lty = c(1, 3:6))
# 
# matplot(x = out_inv[,1],
#         y = out_inv[,-1],
#         type = "l",
#         ylim = c(1e-3, 0.13),
#         xlab = "time",
#         ylab = "abundance",
#         log = "y")
# 
# matplot(x = out_mix[,1],
#         y = out_mix[,-1],
#         type = "l",
#         ylim = c(1e-3, 0.13),
#         xlab = "time",
#         ylab = "abundance",
#         log = "y")
# 
# tail(out_mono)
# NE_mono_eq(pars)
# 
# tail(out_inv)
# tail(out_mix)
# NEeq(pars)[1]
# NCeq(pars)

# Test e ESS dynamics -----------------------------------------------------

elst <- exp(seq(log(1e-6), log(1), length = 1000))
times <- seq(0, 500, by = 0.1)

niter <- 1000
e_use <- rep(NA, niter)  # save best e for each iteration
e_use[1] <- pars["e"]    # initial value
Nlst <- rep(NA, niter)   # save abundances
Ilst <- rep(NA, niter)   # save invasion rates
Nlst[1] <- NEeq(pars)[1] # initial value
Ilst[1] <- 0             # initial invasion rate

## Check invasion rates
n <- 2
while(n<=niter) {
  deltae <- runif(1, -1e-2, 1e-2)
  
  pars_new <- pars
  pars_new["e"] <- pmax(pars["e"]+deltae, 0)
  
  #invasion rate into system with old pars
  Inv<-(pars["r"]*REeq(pars)-(pars_new["e"]+pars["m"]))
  
  #check equilibrium
  Nstar <- suppressWarnings(try(NEeq(pars_new)[1], silent = TRUE))
  
  #accept new value if possible
  if(!is.character(Nstar) && !is.nan(Nstar) && Nstar>0 && Inv>0) {
    pars["e"] <- pars_new["e"]
    Ilst[n] <- Inv
    Nlst[n] <- Nstar
  }
  
  #store values
  e_use[n] <- pars["e"]
  
  n <- n+1
  if(n/10 == floor(n/10)) {
    print(round(n/niter,2))
  }
}
euse <- pars["e"] #save "best" e

# plot(e_use, xlab = "iteration", ylab = "e", type = "l", log = "xy")
# ps<-which(!is.na(Ilst) & Ilst>0)
# plot(ps, Ilst[ps], type = "l", xlab = "iteration", ylab = "invasion", log = "xy")
# ps<-which(!is.na(Nlst) & Ilst>0)
# plot(ps, Nlst[ps], type = "l", xlab = "iteration", ylab = "NE", log = "xy")

## plot instantaneous invasion vs. e
inv_rates <- (pars["r"]*REeq(pars)-(elst+pars["m"]))
# plot(elst, inv_rates, type = "l", log = "x", ylim = c(-1e-3, 1e-3))
# abline(h = 0, lty = 3)
# abline(v = pars["e"], lty = 3)

## plot eq. abundance vs. e
Nest <- sapply(1:length(elst), function(x) {pars_tmp <- pars; pars_tmp["e"] <- elst[x]; suppressWarnings(try(NEeq(pars_tmp)[1], silent = TRUE))})
# plot(elst, Nest, type = "l", log = "x")
# abline(h = 0, lty = 3)
# abline(v = pars["e"], lty = 3)
# #Can't drop e any further, as this would lead to NE*<0
# #Note also - maximum e value around 0.9, at which equilibrium abundance also < 0

#run ode at new parameters
times <- seq(1, 1000, by = 1)
pars_sim <- pars
pars_sim["e"] <- euse

yini <- c(NE = NEeq(pars_sim)[1],
          NC = NCeq(pars_sim),
          E  = Eeq(pars_sim)[1],
          RE = REeq(pars_sim),
          RC = RCeq(pars_sim),
          S  = Seq(pars_sim)[1])
out <- data.frame(ode(y = yini, t = times, fun = ECmod, parms = pars_sim))
# matplot(out[, 1], out[, 2:3], type = "l", xlab = "time", ylab = "abundance")
# abline(h = 0, lty = 3)

# At optimal parameters, get coexistence
pars_sim["e"] <- euse*0.75
out <- data.frame(ode(y = yini, t = times, fun = ECmod, parms = pars_sim))
# matplot(out[, 1], out[, 2:3], type = "l", xlab = "time", ylab = "abundance")
# abline(h = 0, lty = 3)
# If we reduce e further, both species go extinct

# Starting points after the decline begins:
alleepoint <- NEeq(pars)[2]
prepos <- max(which(out$NE>alleepoint))-100 #time immediately before threshold is crossed
postpos <- max(which(out$NE>alleepoint))+100 #time immediately after threshold is crossed
yini_new <- as.numeric(out[prepos, -1])
names(yini_new) <- colnames(out)[-1]
yini_new2 <- as.numeric(out[postpos, -1])
names(yini_new2) <- colnames(out)[-1]

# abline(h = alleepoint, v = c(prepos, postpos), lty = 2)
# Here, we are still *just* above the Allee threshold-
# Meaning we can "rescue" the population with the original e

# Drop e further:
pars_sim["e"] <- euse*0.5
out <- data.frame(ode(y = yini_new, t = times, fun = ECmod, parms = pars_sim))
# matplot(out[, 1], out[,2:3], type = "l", xlab = "time", ylab = "abundance")
# abline(h = 0, lty = 3)
# Even faster extinction - i.e. dNE/dt for e below critical value is negative -
# No longer an ESS

## Try original e:
times_long <- seq(0, 5000, by = 1)
pars_sim["e"] <- euse
out1 <- data.frame(ode(y = yini_new, t = times_long, fun = ECmod, parms = pars_sim))
# matplot(out1[, 1], out1[, 2:3], type = "l", xlab = "time", ylab = "abundance")
# abline(h = 0, lty = 3)
# Rescue! - i.e. dNE/dt for e at threshold is positive
# Suggests that selective pressure
# After drop to extinction begins is actually for
# Higher e, which would create the "stability"
# Gradient that we are looking for.

## If we try with the same e after the Allee threshold has been crossed
## then we can't rescue the population anymore.
pars_sim["e"] <- euse
out2 <- data.frame(ode(y = yini_new2, t = times_long, fun = ECmod, parms = pars_sim))
# matplot(out2[, 1], out2[, 2:3], type = "l", xlab = "time", ylab = "abundance")
# abline(h = 0, lty = 3)
# Note, though, we do need to wait a bit after crossing the Allee threshold, to keep
# transient effects of RE from allowing system recovery.

# Relationships between parameters ----------------------------------------

## Literature parameter values
pars  <- c(r  = 1.66,
           e  = unname(euse), #<ESS>
           m  = 0.11,
           q  = 0.65,
           g  = 138.01,
           qz = 1,
           mz = 1.05,
           d  = 0.1,
           a  = 0.01,
           S0 = 1.25)

varyparm <- function(pars, parmname, lower = 0.5, upper = 2, doplot = TRUE, sqlng = 1000, logplot = "x") {
  pars_tmp <- pars
  
  if(sum(grep("x", logplot))>0) {
    parssq <- exp(seq(log(pars[parmname]*lower), log(pars[parmname]*upper), length = sqlng))
  } else {
    parssq <- seq(pars[parmname]*lower, pars[parmname]*upper, length = sqlng)
  }
  
  eqmat <- matrix(nrow = sqlng, ncol = 8)
  colnames(eqmat)<-c(parmname, "NE_mono", "NE", "NC", "E", "RE", "RC", "S")
  
  for(i in 1:sqlng) {
    pars_tmp[parmname] <- parssq[i]
    eqmat[i, 1] <- parssq[i]
    eqmat[i, 2] <- suppressWarnings(NE_mono_eq(pars_tmp))
    eqmat[i, 3] <- suppressWarnings(NEeq(pars_tmp)[1])
    eqmat[i, 4] <- suppressWarnings(NCeq(pars_tmp))
    eqmat[i, 5] <- suppressWarnings(Eeq(pars_tmp)[1])
    eqmat[i, 6] <- suppressWarnings(REeq(pars_tmp))
    eqmat[i, 7] <- suppressWarnings(RCeq(pars_tmp))
    eqmat[i, 8] <- suppressWarnings(Seq(pars_tmp)[1])
  }
  eqmat[!is.finite(eqmat)] <- 0
  eqmat[eqmat<0] <- 0
  eqmat <- data.frame(eqmat)
  eqmat[eqmat[, "NE"] == 0, c("NC", "E", "RE", "RC")]<-0
  eqmat[eqmat[, "NE"] == 0, c("S")] <- pars["S0"]
  
  return(eqmat)
}

#Show effects of parameters
#e and d - ones that we are probably most interested in
e_vary<-varyparm(pars, parmname = "e", upper = 500)
d_vary<-varyparm(pars, parmname = "d", upper = 4.5)

#other parameters
# r_vary <- varyparm(pars, parmname = "r", upper = 10)
# m_vary <- varyparm(pars, parmname = "m")
# q_vary <- varyparm(pars, parmname = "q")
# g_vary <- varyparm(pars, parmname = "g")
# qz_vary <- varyparm(pars, parmname = "qz")
# mz_vary <- varyparm(pars, parmname = "mz")
# a_vary <- varyparm(pars, parmname = "a")
# S0_vary <- varyparm(pars, parmname = "S0")

# Plot data prep ----------------------------------------------------------

## e + d plots data ##

## Copy from previous tests
e_effect <- e_vary
d_effect <- d_vary

## Way to cut geom_line when it equals zero
# e_effect[3:8][e_effect[3:8] == 0] <- NA
e_effect[e_effect == 0] <- NA
d_effect[d_effect == 0] <- NA

## Add new column for time
# e_effect$t <- seq(1,1000, by = 1)

e_effect$e[min(which(e_effect$NE>0))]
e_effect$e[max(which(e_effect$NE>0))]

e_effect$e[min(which(e_effect$NE_mono>0))]
e_effect$e[max(which(e_effect$NE_mono>0))]

d_effect$d[min(which(d_effect$NE>0))]
d_effect$d[max(which(d_effect$NE>0))]

d_effect$d[max(which(d_effect$NE_mono>0))]

# Plots for [e] effects ---------------------------------------------------

## Invasion rate plot

library(ggplot2)
library(scales)

invasion <- data.frame(elst, inv_rates)
# invasion$elst_log10 <- log10(invasion$elst)

# Custom code for powers of 10 in axis labels
exponents_format <- function(x) {ifelse(x == 0, "0",
                                        parse(text = gsub("[+]", "", gsub("e", " %*% 10^", scientific_format()(x)))))}

ei_p <-
  ggplot(invasion)+
  geom_line(aes(x = elst,
                y = inv_rates),
            color = "black",
            size = 2,
            lineend = "round")+
  geom_vline(xintercept = e_effect$e[min(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "dotdash")+
  geom_hline(yintercept = 0,
             color = "black",
             size = 1,
             linetype = "dashed")+
  scale_x_log10(breaks = trans_breaks("log10", function(x) 10^x),
                labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(label = number_format(accuracy = 0.0001),
                     limits = c(-0.001, 0.001))+
  ylab(expression(paste(italic("N"["E"]), " mutant invasion rate")))+
  xlab(expression(paste("Exoenzyme investment ", "[", italic("e"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15,
                                    # margin = margin(t = 0, r = 20, b = 0, l = 0)
                                    ),
        axis.title.x = element_text(size = 15,
                                    # margin = margin(t = 10, r = 0, b = 0, l = 0)
                                    ),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.ticks = element_line(size = 2, colour = "black"),
        # plot.margin = unit(c(t = 0.5, r = 0.5, b = 0.5, l = 0.5), "cm")
        )

## e thresholds

library(ggplot2)
library(scales)

thresholds <- data.frame(elst, Nest)

et_p <-
  ggplot(thresholds)+
  geom_line(aes(x = elst,
                y = Nest),
            color = "black",
            size = 2,
            lineend = "round")+
  geom_vline(xintercept = e_effect$e[min(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "dotdash")+
  geom_hline(yintercept = 0,
             color = "black",
             size = 1,
             linetype = "dashed")+
  geom_vline(xintercept = e_effect$e[max(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "solid")+
  scale_x_log10(breaks = trans_breaks("log10", function(x) 10^x),
                labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(limits = c(-0.007, 0.15),
                     breaks = c(0, 0.05, 0.10, 0.15))+
  ylab(expression(paste(italic("N"["E"]), " abundance (mg L"^-1, ")")))+
  xlab(expression(paste("Exoenzyme investment ", "[", italic("e"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15,
                                    # margin = margin(t = 0, r = 20, b = 0, l = 0)
                                    ),
        axis.title.x = element_text(size = 15,
                                    # margin = margin(t = 10, r = 0, b = 0, l = 0)
                                    ),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.ticks = element_line(size = 2, colour = "black"),
        # plot.margin = unit(c(t = 0.5, r = 0.5, b = 0.5, l = 0.5), "cm")
        )

## e extinction

library(ggplot2)

ex_p <-
  ggplot(out)+
  geom_line(aes(x = time,
                y = NE,
                color = "#56B4E9"),
            size = 2,
            lineend = "round")+
  geom_line(aes(x = time,
                y = NC,
                color = "#CC79A7"),
            size = 2,
            linetype = "dashed",
            lineend = "round")+
  geom_hline(yintercept = alleepoint, # 0.002123498
             color = "red",
             size = 1,
             linetype = "dotdash")+
  geom_hline(yintercept = 0,
             color = "black",
             size = 1,
             linetype = "dashed")+
  geom_vline(xintercept = prepos, # 94
             color = "black",
             size = 1,
             linetype = "dotted")+
  geom_vline(xintercept = postpos, # 294
             color = "black",
             size = 1,
             linetype = "dotted")+
    scale_y_continuous(breaks = c(0, 0.01, 0.02, 0.03, 0.04, 0.05, 0.06),
                       limits = c(0, 0.061))+
  scale_color_manual(name = NULL, values = c("#56B4E9", "#CC79A7"), labels = c(expression(paste(italic(N[E]))),
                                                                               expression(paste(italic(N[C])))))+
  ylab(expression(paste("Abundance (mg L"^-1, ")")))+
  xlab("Time (h)")+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15,
                                    # margin = margin(t = 0, r = 20, b = 0, l = 0)
                                    ),
        axis.title.x = element_text(size = 15,
                                    # margin = margin(t = 10, r = 0, b = 0, l = 0)
                                    ),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.ticks = element_line(size = 2, colour = "black"),
        legend.text = element_text(size = 15, colour = "black"),
        legend.position = c(0.90, 0.90), # (h, v)
        legend.background = element_blank(),
        legend.key = element_rect(colour = "transparent",
                                  fill = "transparent"),
        # plot.margin = unit(c(t = 0.5, r = 0.5, b = 0.5, l = 0.5), "cm")
        )

## e rescue

library(ggplot2)

er_p <-
  ggplot(out1)+
  geom_line(aes(x = time,
                y = NE,
                color = "#56B4E9"),
            size = 2,
            lineend = "round")+
  geom_line(aes(x = time,
                y = NC,
                color = "#CC79A7"),
            size = 2,
            linetype = "dashed",
            lineend = "round")+
  geom_hline(yintercept = alleepoint, # 0.002123498
             color = "red",
             size = 1,
             linetype = "dotdash")+
  geom_hline(yintercept = 0,
             color = "black",
             size = 1,
             linetype = "dashed")+
  scale_y_continuous(breaks = c(0, 0.01, 0.02, 0.03, 0.04, 0.05, 0.06),
                     limits = c(0, 0.061))+
  scale_color_manual(name = NULL, values = c("#56B4E9", "#CC79A7"), labels = c(expression(paste(italic(N[E]))),
                                                                               expression(paste(italic(N[C])))))+
  ylab(expression(paste("Abundance (mg L"^-1, ")")))+
  xlab("Time (h)")+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15,
                                    # margin = margin(t = 0, r = 20, b = 0, l = 0)
                                    ),
        axis.title.x = element_text(size = 15,
                                    # margin = margin(t = 10, r = 0, b = 0, l = 0)
                                    ),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.ticks = element_line(size = 2, colour = "black"),
        legend.text = element_text(size = 15, colour = "black"),
        legend.position = c(0.90, 0.90), # (h, v)
        legend.background=element_blank(),
        legend.key = element_rect(colour = "transparent",
                                  fill = "transparent"),
        # plot.margin = unit(c(t = 0.5, r = 0.5, b = 0.5, l = 0.5), "cm")
        )

library(ggpubr)

patchwork <- ggarrange(ei_p, et_p,
                      ex_p, er_p,
                      labels = c("(A)", "(B)", "(C)", "(D)"),
                      ncol = 2,
                      nrow = 2,
                      align = "hv")

ggsave("Fig3_e effect plots.pdf",
       plot = patchwork,
       device = "pdf",
       width = 297,
       height = 210,
       units = "mm",
       dpi = 600)

# Plots for [e] thresholds ---------------------------------------------------

library(ggplot2)
library(scales)

# NE-mono, NE-NC-mixture
NEp <-
  ggplot(data = e_effect)+
  geom_line(aes(x = e,
                y = NE_mono,
                color = "#56B4E9"),
            size = 2,
            lineend = "round")+
  geom_line(aes(x = e,
                y = NE,
                color = "#E69F00"),
            size = 2,
            lineend = "round")+
  geom_vline(xintercept = e_effect$e[min(which(e_effect$NE_mono>0))], # critical [e] for monoculture
             color = "black",
             size = 1,
             linetype = "dotdash")+
  geom_vline(xintercept = e_effect$e[min(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "dotdash")+
  geom_vline(xintercept = e_effect$e[max(which(e_effect$NE_mono>0))],
             color = "black",
             size = 1,
             linetype = "solid")+
  geom_vline(xintercept = e_effect$e[max(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "solid")+
  # geom_vline(xintercept = e_effect$e[max(which(e_effect$NE_mono>0))], # max [e] limit for monoculture but outside plot
  #             color = "black",
  #             size = 1,
  #             linetype = "solid")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  coord_cartesian(xlim = c(0.0005, 0.35),
                  ylim = c(0.003, 0.15))+
  scale_color_manual(name = NULL, values = c("#56B4E9", "#E69F00"),
                     labels = c(expression(paste(italic("N"["E"]), " monoculture")),
                                expression(paste(italic("N"["E"]), " - ", italic("N"["C"]), " mixture"))))+
  ylab(expression(atop("Producer "*"["*italic("N"["E"])*"]", "abundance (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Exoenzyme investment ", "[", italic("e"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"),
        legend.text = element_text(size = 15, colour = "black", hjust = 0),
        legend.position = c(0.5, 0.30),
        legend.background = element_blank(),
        legend.key = element_rect(colour = "transparent",
                                  fill = "transparent"))

# NC
NCp <- 
  ggplot(data = e_effect)+
  geom_line(aes(x = e,
                y = NC),
            color = "#CC79A7",
            size = 2,
            lineend = "round")+
  geom_vline(xintercept = e_effect$e[min(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "dotdash")+
  # geom_hline(yintercept = 0,
  #            color = "black",
  #            size = 1,
  #            linetype = "dashed")+
  geom_vline(xintercept = e_effect$e[max(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "solid")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  coord_cartesian(xlim = c(0.0005, 0.35),
                  ylim = c(0.0003, 0.15))+
  ylab(expression(atop("Cheater "*"["*italic("N"["C"])*"]", "abundance (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Exoenzyme investment ", "[", italic("e"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"))

# RE
REp <- 
  ggplot(data = e_effect)+
  geom_line(aes(x = e,
                y = RE),
            color = "#009E73",
            size = 2,
            lineend = "round")+
  geom_vline(xintercept = e_effect$e[min(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "dotdash")+
  # geom_hline(yintercept = 0,
  #            color = "black",
  #            size = 1,
  #            linetype = "dashed")+
  geom_vline(xintercept = e_effect$e[max(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "solid")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  coord_cartesian(xlim = c(0.0005, 0.35),
                  ylim = c(0.003, 0.15))+
  ylab(expression(atop("Producer res.", "["*italic("R"["E"])*"]"*" (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Exoenzyme investment ", "[", italic("e"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"))

# RC
RCp <- 
  ggplot(data = e_effect)+
  geom_line(aes(x = e,
                y = RC),
            color = "#F0E442",
            size = 2,
            lineend = "round")+
  geom_vline(xintercept = e_effect$e[min(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "dotdash")+
  # geom_hline(yintercept = 0,
  #            color = "black",
  #            size = 1,
  #            linetype = "dashed")+
  geom_vline(xintercept = e_effect$e[max(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "solid")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  coord_cartesian(xlim = c(0.0005, 0.35),
                  ylim = c(0.003, 0.15))+
  ylab(expression(atop("Cheater res.", "["*italic("R"["C"])*"]"*" (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Exoenzyme investment ", "[", italic("e"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"))

# E
Ep <- 
  ggplot(data = e_effect)+
  geom_line(aes(x = e,
                y = E),
            color = "#0072B2",
            size = 2,
            lineend = "round")+
  geom_vline(xintercept = e_effect$e[min(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "dotdash")+
  # geom_hline(yintercept = 0,
  #            color = "black",
  #            size = 1,
  #            linetype = "dashed")+
  geom_vline(xintercept = e_effect$e[max(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "solid")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  coord_cartesian(xlim = c(0.0005, 0.35),
                  ylim = c(0.000005, 0.005))+
  ylab(expression(atop("Exoenzyme", "["*italic("E")*"]"*" (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Exoenzyme investment ", "[", italic("e"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"))

# S
Sp <- 
  ggplot(data = e_effect)+
  geom_line(aes(x = e,
                y = S),
            color = "#D55E00",
            size = 2,
            lineend = "round")+
  geom_vline(xintercept = e_effect$e[min(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "dotdash")+
  # geom_hline(yintercept = 0,
  #            color = "black",
  #            size = 1,
  #            linetype = "dashed")+
  geom_hline(yintercept = 1.25,
             color = "black",
             size = 1,
             linetype = "dotted")+
  geom_vline(xintercept = e_effect$e[max(which(e_effect$NE>0))],
             color = "red",
             size = 1,
             linetype = "solid")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  coord_cartesian(xlim = c(0.0003, 0.3),
                  ylim = c(0.01, 2))+
  ylab(expression(atop("Substrate", "["*italic("S")*"]"*" (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Exoenzyme investment ", "[",italic("e"),"]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"))

library(ggpubr)

patchwork <- ggarrange(NEp, NCp,
                      REp, RCp,
                      Ep, Sp,
                      labels = c("(A)", "(B)", "(C)", "(D)", "(E)", "(F)"),
                      ncol = 2,
                      nrow = 3,
                      align = "hv",
                      hjust = 0)

ggsave("Fig2_e plots.pdf",
       plot = patchwork,
       device = "pdf",
       width = 297,
       height = 210,
       units = "mm",
       dpi = 600)

# Plots for [d] thresholds ---------------------------------------------------

library(ggplot2)
library(scales)

NEp <- 
  ggplot(data = d_effect)+
  geom_line(aes(x = d,
                y = NE_mono,
                color = "#56B4E9"),
            size = 2,
            lineend = "round")+
  geom_line(aes(x = d,
                y = NE,
                color = "#E69F00"),
            size = 2,
            lineend = "round")+
  # geom_hline(yintercept = 0,
  #            color = "black",
  #            size = 1,
  #            linetype = "dashed")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_color_manual(name = NULL, values = c("#56B4E9", "#E69F00"),
                     labels = c(expression(paste(italic("N"["E"]), " monoculture")),
                                expression(paste(italic("N"["E"]), " - ", italic("N"["C"]), " mixture"))))+
  ylab(expression(atop("Producer "*"["*italic("N"["E"])*"]", "abundance (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Diffusion rate ", "[", italic("d"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"),
        legend.text = element_text(size = 15, colour = "black", hjust = 0),
        legend.position = c(0.5, 0.30),
        legend.background=element_blank(),
        legend.key = element_rect(colour = "transparent",
                                  fill = "transparent"))

# NC
NCp <- 
  ggplot(data = d_effect)+
  geom_line(aes(x = d,
                y = NC),
            color = "#CC79A7",
            size = 2,
            lineend = "round")+
  # geom_hline(yintercept = 0,
  #            color = "black",
  #            size = 1,
  #            linetype = "dashed")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  ylab(expression(atop("Cheater "*"["*italic("N"["C"])*"]", "abundance (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Diffusion rate ", "[", italic("d"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"))

# RE
REp <- 
  ggplot(data = d_effect)+
  geom_line(aes(x = d,
                y = RE),
            color = "#009E73",
            size = 2,
            lineend = "round")+
  # geom_hline(yintercept = 0,
  #            color = "black",
  #            size = 1,
  #            linetype = "dashed")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  ylab(expression(atop("Producer res.", "["*italic("R"["E"])*"]"*" (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Diffusion rate ", "[", italic("d"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"))

# RC
RCp <- 
  ggplot(data = d_effect)+
  geom_line(aes(x = d,
                y = RC),
            color = "#F0E442",
            size = 2,
            lineend = "round")+
  # geom_hline(yintercept = 0,
  #            color = "black",
  #            size = 1,
  #            linetype = "dashed")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  ylab(expression(atop("Cheater res.", "["*italic("R"["C"])*"]"*" (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Diffusion rate ", "[", italic("d"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"))

# E
Ep <- 
  ggplot(data = d_effect)+
  geom_line(aes(x = d,
                y = E),
            color = "#0072B2",
            size = 2,
            lineend = "round")+
  # geom_hline(yintercept = 0,
  #            color = "black",
  #            size = 1,
  #            linetype = "dashed")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  ylab(expression(atop("Exoenzyme", "["*italic("E")*"]"*" (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Diffusion rate ", "[", italic("d"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"))

# S
Sp <- 
  ggplot(data = d_effect)+
  geom_line(aes(x = d,
                y = S),
            color = "#D55E00",
            size = 2,
            lineend = "round")+
  geom_hline(yintercept = 1.25,
             color = "black",
             size = 1,
             linetype = "dotted")+
  scale_x_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  scale_y_continuous(trans = "log10",
                     breaks = trans_breaks("log10", function(x) 10^x),
                     labels = trans_format("log10", math_format(10^.x)))+
  coord_cartesian(#xlim = c(0.0003, 0.3),
                  ylim = c(0.01, 2))+
  ylab(expression(atop("Substrate", "["*italic("S")*"]"*" (mg L"^-1*")")))+ # For atop() => *=space, comma=new line
  xlab(expression(paste("Diffusion rate ", "[", italic("d"), "]", " h"^-1)))+
  theme_bw()+
  theme(panel.grid = element_blank(),
        axis.title.y = element_text(size = 15),
        axis.title.x = element_text(size = 15),
        axis.text  = element_text(size = 15, colour = "black"),
        axis.text.y = element_text(hjust = 0),
        axis.ticks = element_line(size = 2, colour = "black"))

library(ggpubr)

patchwork <- ggarrange(NEp, NCp,
                       REp, RCp,
                       Ep, Sp,
                       labels = c("(A)", "(B)", "(C)", "(D)", "(E)", "(F)"),
                       ncol = 2,
                       nrow = 3,
                       align = "hv",
                       hjust = 0)

ggsave("Fig4_d plots.pdf",
       plot = patchwork,
       device = "pdf",
       width = 297,
       height = 210,
       units = "mm",
       dpi = 600)
